<% content_for :title, 'Edit Provider' %>

<% content_for :breadcrumbs do %>
  <ol class="breadcrumb">
    <li class="breadcrumb-item"><%= link_to 'Dashboard', main_app.root_path %></li>
    <li class="breadcrumb-item"><%= link_to 'Echo', prompts_path %></li>
    <li class="breadcrumb-item"><%= link_to 'Providers', providers_path %></li>
    <li class="breadcrumb-item active">Edit Provider</li>
  </ol>
<% end %>

<div class="content-container">
  <h4 class="header-underline">Edit Provider</h4>
  <%= render 'form', provider: @provider %>
</div>
