<% if comment %>
  <% title = "#{comment.commentable.class.to_s.capitalize} ##{comment.commentable.id}" %>
  <% if comment.commentable.title? %>
    <% title = comment.commentable.title %>
  <% end %>
  <%= presenter.verb %> a <%= link_to 'comment', presenter.comment_path(anchor: dom_id(comment)) %> on <%= link_to title, presenter.comment_path %>.
<% else %>
  <% if activity.action == 'destroy' %>
    deleted a comment.
  <% else %>
    <%= presenter.verb %> a comment which has since been deleted.
  <% end %>
<% end %>
