<li class="nav-item dropdown">
  <a href="javascript:void(0)" class="nav-link dropdown-toggle no-caret-xl" id="configurationDropdown" title="Configuration" role="button" data-bs-toggle="dropdown" aria-expanded="false">
    <i class="fa-solid fa-cog fa-fw d-none d-lg-inline" title="Configuration"></i>
    <span class="d-inline d-lg-none">Configuration</span>
  </a>
  <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="configurationDropdown">
    <%= yield %>
  </ul>
</li>
