<li class="nav-item dropdown me-0 mb-3 mb-lg-0">
  <a class="nav-link dropdown-toggle pe-0 py-lg-0 d-flex align-items-center no-caret-xl" href="javascript:void(0)" role="button" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false" id="user-profile">
    <%= avatar_image(current_user, size: 32) %>
    <span class="d-block d-lg-none ms-1"><%= current_user.name %></span>
  </a>
  <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="user-profile">
    <%= yield %>
    <li>
      <%= link_to main_app.logout_path, class: 'dropdown-item', data: { turbo: false } do %>
        <i class="fa-solid fa-arrow-right-from-bracket"></i>
        <span class="ms-1">Logout</span>
      <% end %>
    </li>
  </ul>
</li>
