document.addEventListener('turbo:load', function(){
<%
Dradis::Plugins::with_feature(:addon, include_disabled: true).sort_by(&:plugin_description).each do |plugin|
  begin
    plugin_path = ActiveSupport::Inflector.underscore(ActiveSupport::Inflector.deconstantize(plugin.name))
    %>
    <%= require_asset "#{plugin_path}/manifests/hera.js" %>
    <% sleep 1 %>
    <%
  rescue Sprockets::FileNotFound;
  end
end
%>
});
