//= link application.css
//= link errors.css
//= link hera.css
//= link setup/setup.css

//= link legacy.application.js
//= link hera.js

//= link_tree ../../javascript .js
//= link_tree ../../../vendor/javascript .js

//= link_tree ../images

//= link_tree ../../../vendor/assets
