<div class="d-flex align-items-center justify-content-around flex-wrap w-100">
  <%= link_to project_boards_path(current_project), class: 'btn btn-primary btn-lg mb-2 px-5' do %>
    <i class="fa-brands fa-trello me-2"></i> Go To Methodologies
  <% end %>
</div>
