<% cache('navbar-help') do %>
<li class="nav-item dropdown">
  <a href="javascript:void(0)" class="nav-link dropdown-toggle no-caret-xl" data-bs-toggle="dropdown" data-behavior="close-collapse" title="Help">
    <i class="fa-solid fa-question d-none d-lg-inline" title="Help"></i>
    <span class="d-inline d-lg-none">Help</span>
  </a>

  <ul class="dropdown-menu dropdown-menu-end">
    <li>
      <a href="javascript:void(0)" class="js-try-pro dropdown-item" data-term="training-course" data-url="https://dradis.com/academy/dradis-course/?utm_source=ce&utm_medium=app&utm_campaign=try-pro&utm_term=training-course">Free training course</a>
    </li>
    <li>
      <a href="https://dradis.com/support/guides/projects/?utm_source=ce&utm_medium=app&utm_campaign=support&utm_term=projects101" target="_blank" class="dropdown-item">Projects 101</a>
    </li>
    <li>
      <a href="https://dradis.com/support/guides/troubleshooting/?utm_source=ce&utm_medium=app&utm_campaign=support&utm_term=troubleshooting" target="_blank" class="dropdown-item">Troubleshooting</a>
    </li>
    <li>
      <div class="dropdown-divider"></div>
    </li>

    <%= render partial: "layouts/hera/navbar/main_nav/help_menu/#{Dradis.edition}" %>

    <li>
      <a href="https://github.com/dradis/dradis-ce/issues" target="_blank" class="dropdown-item">Report an issue</a>
    </li>
    <li>
      <a href="https://dradis.com/support/?utm_source=ce&utm_medium=app&utm_campaign=support&utm_term=support" target="_blank" class="dropdown-item">Support website</a>
    </li>
    <li>
      <a href="https://discuss.dradis.com?utm_source=ce&utm_medium=app&utm_campaign=forum" target="_blank" class="dropdown-item">Community forums</a>
    </li>
    <li>
      <div class="dropdown-divider"></div>
    </li>
    <li>
      <a href="https://dradis.com/careers/?utm_source=ce&utm_medium=app&utm_campaign=careers" target="_blank" class="dropdown-item">We're hiring</a>
    </li>
    <li>
      <div class="dropdown-divider"></div>
    </li>
    <li>
      <a href="javascript:void(0)" class="js-try-pro dropdown-item" data-term="try-pro" data-url="https://dradis.com/pro/pages/upgrade.html">Try Dradis Pro</a>
    </li>

  </ul>
</li>
<% end %>
