<!-- Privacy-friendly analytics by Plausible -->
<script async src="https://plausible.io/js/pa-SCJ7kmNrz_jMArRcxrba2.js"></script>
<script>
window.plausible=window.plausible||function(){(plausible.q=plausible.q||[]).push(arguments)},plausible.init=plausible.init||function(i){plausible.o=i||{}};
plausible.init({captureOnLocalhost:true})
</script>
