<div class="d-flex align-items-center justify-content-around flex-wrap w-100">
  <p>Lists can represent task categories (e.g. External, Internal, Webapp, etc.), task statuses (e.g. Next, In Progress, Ready for Review, Completed), or they can be labeled in any way that makes the most sense for your team's workflow.</p>
  <%= link_to '#modal-list-new', class: 'btn btn-primary btn-lg mb-2 px-5', data: { bs_toggle: 'modal' } do %>
    <i class="fa-solid fa-plus"> </i> Add List
  <% end %>
</div>
