<noscript>
  <div class="bg-white">
    <div class="alert alert-danger">
      <h5>Dradis requires JavaScript</h5>
      <p>Please <strong>allow JavaScript</strong> to get the most flawless experience!</p>
    </div>
  </div>
</noscript>
