<div id="modal_delete_node" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="modal-title" aria-hidden="true">
  <div class="modal-dialog">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="modal-title">Delete node?</h5>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-hidden="true">
          <span class="visually-hidden">Close modal</span>
        </button>
      </div>
      <div class="modal-body">
        <p>Are you sure you want to delete the "<strong><%= @node.label %></strong>" node from your project?</p>
        <p>When you delete a node, all of the following are deleted with it:</p>
        <ul>
          <li>Notes</li>
          <li>Attachments</li>
          <li>Evidence</li>
          <li>Child nodes (and their children)</li>
        </ul>
      </div>
      <div class="modal-footer">
        <%= link_to 'Delete', [@node.project, @node], :class => 'btn btn-danger', :method => :delete %>
        <button class="btn" type="button" data-bs-dismiss="modal" aria-hidden="true">Close</button>
      </div>
    </div>
  </div>
</div>
