<nav data-behavior="breadcrumbs-nav">
  <ol class="breadcrumb">
    <li class="breadcrumb-item">
        <%= link_to current_project.name, project_path(current_project) %>
      </li>
    <li class="breadcrumb-item">
      <%= link_to @board.node.label, project_boards_path(current_project, node_id: @board.node_id) %>
    </li>
    <li class="breadcrumb-item">
      <%= link_to "#{@board.name} - #{@list.name}", project_board_path(current_project, @board) %>
    </li>
    <li class="breadcrumb-item active">
      <%= @card.try!(:name) || 'New task' %>
    </li>
  </ol>
</nav>
