<div class="alert alert-warning mb-0 d-none" data-behavior="project-teaser">
  <h3>This isn't the project you're looking for...</h3>
  <p>It was a good guess though!</p>
  <p>
    If you run multiple concurrent assessments, consider <strong>Dradis Pro</strong>. You get:
    <ul class="list-disc">
      <li>Unlimited projects.</li>
      <li>Custom branded Word/Excel reports.</li>
      <li>Reusable Issue Library.</li>
      <li>Scanning tool normalization layer.</li>
      <li>... and much more!</li>
    </ul>
    <p class="mb-0">Self-hosted. Battle-tested. Compare <a href="https://dradis.com/pro/editions.html?utm_source=ce&utm_medium=app&utm_campaign=url" target="_blank">Dradis Editions</a>.</p>
  </p>
</div>
