<% content_for :content do %>
  <% content_for :sidebar do %>
    <%= render 'nodes/sidebar' %>
  <% end %>
  <%= render 'nested_node_resources/poller_alerts' %>
  <%= yield %>
<% end %>

<%= render template: 'layouts/hera/project' %>
