<% css_class = local_assigns[:dots_menu] ? 'dropdown-item' : '' %>

<%= link_to \
      main_app.subscription_path(
        subscribable,
        subscription: {
          subscribable_type: subscribable.class.to_s,
          subscribable_id: subscribable.id
        }
      ),
      class: "d-none #{css_class}",
      data: {'behavior': 'unsubscribe'},
      method: :delete do %>
  <i class="fa-solid fa-bell-slash fa-fw"></i> Unsubscribe
<% end %>
<%= link_to \
      main_app.subscriptions_path(
        subscribable,
        subscription: {
          subscribable_type: subscribable.class.to_s,
          subscribable_id: subscribable.id
        }
      ),
      class: "d-none #{css_class}",
      data: {'behavior': 'subscribe'},
      method: :post do %>
  <i class="fa-solid fa-bell fa-fw"></i> Subscribe
<% end %>
