<div id="modal_move_note" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="modal-title" aria-hidden="true">
  <%= simple_form_for [current_project, @node, @note], html: { class: 'form-horizontal modal-node-selection-form', data: { node_id: @node.id, hidden_field: '#note_node_id', allow_descendants: true } }  do |f| %>
    <%= f.hidden_field :node_id %>
    <%= f.hidden_field :original_updated_at, value: @note.updated_at.to_i %>
    <div class="modal-dialog">
      <div class="modal-content">
        <div class="modal-header">
          <h5 class="modal-title" id="modal-title">Move note</h5>
          <button type="button" class="btn-close" data-bs-dismiss="modal" aria-hidden="true">
            <span class="visually-hidden">Close modal</span>
          </button>
        </div>
        <div class='modal-body'>
          <p>Where do you want to move the note?</p>

          <div class="tree-modal-box">
            <%= render "layouts/hera/nodes" %>
          </div>
          <p id='move-under'>
            Move under: <strong><span id="current-selection"></span></strong>
          </p>
        </div>
        <div class="modal-footer">
          <button class="btn btn-primary">Move</button>
          <button class="btn" type="button" data-bs-dismiss="modal" aria-hidden="true">Close</button>
        </div>
      </div>
    </div>
  <% end %>
</div>
