//= require jquery3
//= require jquery-ui.min
//= require rails-ujs
//= require jquery.form
//= require jquery.textchange.min
//= require jquery.textile
//= require jquery-fileupload
//= require jquery-hotkeys
//= require d3-4.0.0
//= require local-time
//= require clipboard
//= require tribute
//= require popper
//= require bootstrap

//= require cable

//= require hera/modules/auto_save/local
//= require hera/modules/charts
//= require hera/modules/comments
//= require hera/modules/console_updater
//= require hera/modules/differ
//= require hera/modules/editor_toolbar
//= require hera/modules/base_highlighter
//= require hera/modules/quote_selector
//= require hera/modules/inline_thread_utils
//= require hera/modules/inline_thread_selector
//= require hera/modules/inline_thread_highlighter
//= require hera/modules/inline_thread_turbo
//= require hera/modules/mentions
//= require hera/modules/notifications
//= require hera/modules/rtp_validation
//= require hera/modules/state_button
//= require hera/modules/subscriptions

//= require hera/modules/datatable/main
//= require hera/modules/datatable/checkbox
//= require hera/modules/datatable/delete
//= require hera/modules/datatable/merge
//= require hera/modules/datatable/state
//= require hera/modules/datatable/tag
//= require hera/modules/datatable/validate

//= require hera/vendor/jquery.breadcrumbs
//= require hera/vendor/jquery.treemodal
//= require hera/vendor/jquery.treenav

//= require hera/behaviors
//= require hera/engines

//= require hera/modules/activities_poller
//= require hera/modules/combobox
//= require hera/modules/configurations
//= require hera/modules/export
//= require hera/modules/fileupload
//= require hera/modules/issues
//= require hera/modules/liquid_async
//= require hera/modules/nodes
//= require hera/modules/project_board_colors
//= require hera/modules/search
//= require hera/modules/sidebar
//= require hera/modules/try_pro
//= require hera/modules/uploads

//= require hera/pages/activities
//= require hera/pages/boards
//= require hera/pages/issues
//= require hera/pages/nodes/new_form
//= require hera/pages/projects
//= require hera/pages/qa
//= require hera/pages/upload
