<div class="d-flex align-items-center justify-content-center flex-wrap w-100">
  <%= link_to project_issues_path(current_project), class: 'btn btn-primary btn-lg mb-2 mx-4 px-5' do %>
    <i class="fa-solid fa-bug me-2"></i> Go To Issues
  <% end %>
</div>
