<%# This alert is shown by activities/poller.js if another user deletes the
  current node %>
<div id="node-deleted-alert" class="alert alert-error alert-dismissible d-none">
  <button type="button" class="btn-close" data-bs-dismiss="alert"><span class="visually-hidden">Close alert</span></button>

  <p><strong>Warning</strong>. This whole node has been deleted by another
    user. If you navigate away or refresh your browser, content will be lost.
  </div>

  <% if @evidence %>
    <%# This alert is shown by if another user deletes the current evidence %>
    <div id="evidence-deleted-alert"
       data-evidence-id="<%= @evidence.id %>"
       class="alert alert-danger d-none">
      <p>
        <strong>Warning</strong>. This piece of evidence has been deleted by
        another user since you started viewing it.
      </p>
    </div>

    <%# This alert is shown by activities/poller.js if another user updates the
    current evidence %>
    <div id="evidence-updated-alert" data-evidence-id="<%= @evidence.id %>" class="alert alert-info d-none">
      <p>
        <strong>Warning</strong>. Another user has updated this piece of evidence
        since you started viewing it. Refresh the page to see their changes.
      </p>
    </div>
  <% end %>

  <%# This alert is shown by activities/poller.js if another user deletes the
  current note %>
  <div id="note-deleted-alert" class="alert alert-danger d-none">
    <p>
      <strong>Warning</strong>. This note has been deleted by another user since
      you started viewing it.
    </p>
  </div>

  <%# This alert is shown by activities/poller.js if another user updates the
  current note %>
  <div id="note-updated-alert" class="alert alert-info d-none">
    <p>
      <strong>Warning</strong>. Another user has updated this note since you
      started viewing it. Refresh the page to see their changes.
    </p>
  </div>
