<!doctype html>
<html lang="en" data-theme="auto">
  <head>
    <title><%= [content_for(:title), 'Dradis Community Edition'].compact.join(' | ') %></title>
    <script>(() => { const t = localStorage.getItem('dradis-theme'); if (t) document.documentElement.dataset.theme = t; })();</script>
    <%= stylesheet_link_tag 'application', media: 'all', 'data-turbo-track' => true %>
    <%= javascript_include_tag 'legacy.application', 'data-turbo-track' => true %>
    <%= favicon_link_tag %>
    <%= csrf_meta_tags %>
    <%= csp_meta_tag %>
    <%= javascript_importmap_tags %>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <% cache [:analytics, ::Configuration.usage_sharing_enabled?] do %>
      <%= render 'layouts/plausible' if ::Configuration.usage_sharing_enabled? %>
    <% end %>
  </head>

  <body class="unauthenticated <%= controller_name %> <%= easter_egg_class %>">
    <%= render 'layouts/hera/noscript' %>
    <div class="container h-100">
      <div class="row h-100 align-items-center">
        <div class="col-lg-5">
          <div class="form-container card card-body">
            <div class="logo-icons" data-behavior="logo-icons"></div>
            <%= image_tag easter_egg_logo || 'logo_full_small.png', alt: 'Dradis CE logo', class: 'logo' %>
            <div class="form-container-inner">
              <%= flash_messages %>
              <%= yield %>
            </div>
            <footer>
              <p>Dradis Community Edition - <a href="https://dradis.com/ce/?utm_source=ce&utm_medium=app&utm_campaign=layout">https://dradis.com/ce/</a></p>
            </footer>
          </div>
        </div>
        <div class="col-lg-7 d-none d-lg-block">
          <div class="mission-container">
            <span class="font-monospace" data-behavior="mission-text"></span>
            <span class="mission-text-cursor" data-behavior="mission-text-cursor">&block;</span>
          </div>
        </div>
      </div>
    </div>
  </body>
</html>
