<% content_for :title, "Edit task: #{@card.name}" %>

<%= render partial: 'poller_alerts' %>

<% content_for :breadcrumbs do %>
  <nav>
    <%= render partial: 'breadcrumbs' %>
  </nav>
<% end %>

<div id="cards_editor" class="content-container">
  <h4 class="header-underline">Edit task</h4>
  <div class="note-text-inner">
    <%= render 'form' %>
  </div>
</div>
