<div
  data-behavior="modal-tag-form"
  class="modal fade tags-modal"
  tabindex="-1"
  role="dialog"
  aria-labelledby="modal-tag-header"
  aria-hidden="true"
>
  <div class="modal-dialog">
    <div data-behavior="modal-tag-content" class="modal-content"></div>
  </div>
</div>
