.fa-check {
  color: $green;
}

.fa-grip-vertical {
  cursor: grab;

  &:active {
    cursor: grabbing;
  }
}

.fa-info-circle {
  color: $primary;
}

.fa-times {
  color: $red;
}

.fa-triangle-exclamation {
  color: $yellow;
  position: relative;
  z-index: 0;

  &::after {
    background-color: $black;
    bottom: 0.5rem;
    content: '';
    height: 0.85rem;
    left: 50%;
    position: absolute;
    transform: translateX(-50%);
    width: 0.25rem;
    z-index: -1;
  }
}
