<% if @count > @max_deleted_inline %>
{
  "success": true,
  "jobId": "<%= @job_logger.uid %>"
}
<% elsif @count > 0 %>
{
  "success": true,
  "msg": "<%= "Evidence deleted" %>"
}
<% else %>
{
  "success": false,
  "msg": "<%= "Error deleting Evidence" %>"
}
<% end %>
