<% @ids.each do |id| %>
$notification = $('[data-notification-id="' + <%= id %> + '"]');
$notification.removeClass('unread');
$notification.find('[data-behavior~=notification-read]').remove();
<% end %>

$unreadCount  = $('[data-behavior~=unread-count]');
$unreadCount.text(parseInt($unreadCount.text()) - <%= @updated_count %>);

<% unless @has_unread %>
$('[data-behavior~=notifications-dot]').addClass('d-none');
<% end %>
