<%= render 'error', 
  error_title: 'Unsupported browser',
  status_code: 406,
  quote: "We've jumped way beyond the Red Line into uncharted space. Limited supplies. Limited fuel. No allies. And now no hope!",
  author: 'Commander Adama',
  icon: [9, 'UFO']
%>
