<%= render 'error', 
  error_title: 'Internal Server Error',
  status_code: 500,
  quote: 'There are computational errors in every jump. The further out you jump, the greater the error.',
  author: 'Commander Adama',
  icon: [7, 'Spacecraft']
%>
