<a
  href="javascript:void(0)"
  class="js-try-pro dropdown-item"
  data-term="issuelib"
  data-url="https://dradis.com/pro/pages/issuelib.html">

  <i class="fa-solid fa-book fa-fw"></i> Built-in Issue Library
</a>

<a
  href="javascript:void(0)"
  class="js-try-pro dropdown-item"
  data-term="jira"
  data-url="https://dradis.com/pro/pages/ticketing.html">

  <i class="fa-solid fa-brands fa-jira fa-fw"></i> JIRA Ticket
</a>

<a
  href="javascript:void(0)"
  class="js-try-pro dropdown-item"
  data-term="servicenow"
  data-url="https://dradis.com/pro/pages/ticketing.html">

  <i class="fa-regular fa-square-check fa-fw"></i> ServiceNow Vulnerable Item
</a>

<a
  href="javascript:void(0)"
  class="js-try-pro dropdown-item"
  data-term="devops"
  data-url="https://dradis.com/pro/pages/ticketing.html">

  <i class="fa-regular fa-circle-check fa-fw"></i> DevOps Work Item
</a>


<a
  href="javascript:void(0)"
  class="js-try-pro dropdown-item"
  data-term="remediation"
  data-url="https://dradis.com/pro/pages/remediation.html">

  <i class="fa-solid fa-tasks fa-fw"></i> Built-in Remediation Tracker
</a>
