del {
  background-color: var(--del-bg);
}

ins {
  background-color: var(--ins-bg);
}

.revisions-table {
  tr {
    &.active {
      background-color: var(--revision-active-bg);
    }

    th {
      border-top: none;
      border-bottom: 1px solid var(--border-color);
    }
  }
}
