<div class="inner-content">
  <%= render partial: 'widget' %>
  <div class="header">
    <div class="header-inner">
      <h5 class="header-name">
        <%= link_to index_path do %>
          <%= name.humanize %>
        <% end %>
      </h5>
      <div class="options">
        <%= link_to "##{name.downcase}", data: { bs_toggle: 'collapse', behavior: 'collapse-collection' } do %>
          <i class="fa-solid fa-chevron-up" data-behavior="toggle-chevron"></i><span class="visually-hidden">Toggle <%= name.downcase %> list</span>
        <% end %>
      </div>
    </div>
  </div>

  <div id="<%= name.downcase %>" class="note-list qa-list collapse show">
    <% records.each do |record| %>
      <%= render partial: 'sidebar_item', locals: { record: record } %>
    <% end %>
  </div>
</div>
