<!doctype html>
<html lang="en" data-theme="auto">
  <head>
    <title><%= content_for?(:title) ? yield(:title) : 'Dradis Community Edition' %></title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=0, minimum-scale=1.0, maximum-scale=1.0">
    <%= stylesheet_link_tag 'setup/setup', media: 'all', 'data-turbo-track' => true %>
    <%= favicon_link_tag %>
    <%= csrf_meta_tag %>

    <meta charset="utf-8">
    <%= render 'layouts/plausible' %>
  </head>

  <body class="<%= controller_name %> <%= action_name %>">
    <%= render 'layouts/hera/noscript' %>
    <div class="container">
      <div class="row h-100vh justify-content-center">
        <div class="col d-flex flex-column justify-content-between my-4 setup-wrapper">
          <div class="logo">
            <%= image_tag 'logo_full_small.png', class: 'img-fluid' %>
          </div>

          <div class="container mb-5 pb-5">
            <%= yield %>
          </div>

          <p class="copyright">Dradis Community Edition - <a href="https://dradis.com/ce/?utm_source=ce&utm_medium=app&utm_campaign=layout">https://dradis.com/ce/</a></p>
        </div>
      </div>
    </div>
  </body>
</html>
