<%# this is picked up by javascripts/hera/modules/comments.js.coffee %>
<% cache(@mentionable_users) do %>
  <%= content_tag :meta, '',
    content: tribute_hash(@mentionable_users).to_json,
    data: { fallback_image: image_url(AvatarHelper::DEFAULT_PROFILE_IMAGE) },
    name: 'mentionable-users'
  %>
<% end %>
