<div class="card mb-3">
  <div class="card-body">
    <div class="d-flex align-items-start justify-content-between">
      <div>
        <h5 class="card-title mb-1"><%= agent.name %></h5>
        <div class="d-flex align-items-center gap-2 mb-2">
          <span class="badge bg-secondary"><%= agent.agent_type.humanize %></span>
          <span class="badge <%= agent.enabled? ? 'bg-success' : 'bg-danger' %>">
            <%= agent.enabled? ? 'Enabled' : 'Disabled' %>
          </span>
        </div>
        <div class="text-body-secondary small">
          <span>Provider: <strong><%= agent.provider.name %></strong></span>
          <% if agent.model_override.present? %>
            <span class="ms-3">Model override: <code><%= agent.model_override %></code></span>
          <% end %>
        </div>
      </div>
      <div>
        <%= link_to edit_agent_path(agent), class: 'btn btn-warning btn-sm' do %>
          <i class="fa-solid fa-pencil"></i> Edit
        <% end %>
      </div>
    </div>
  </div>
</div>
