<% content_for :title, "#{@node.label} - edit note" %>

<% content_for :breadcrumbs do %>
  <nav>
    <%= render partial: 'breadcrumbs' %>
  </nav>
<% end %>

<div class="content-container">
  <h4 class="header-underline">Edit note</h4>
  <div class="note-text-inner">
    <%= render "form" %>
  </div>
</div>
