<nav>  
  <ol class="breadcrumb">
    <li class="breadcrumb-item">
        <%= link_to current_project.name, project_path(current_project) %>
      </li>
    <li class="breadcrumb-item">
      <%= link_to 'All issues', project_issues_path(current_project) %>
    </li>
    <li class="breadcrumb-item active">
      <%= (@issue.title? ? @issue.title : "Issue ##{@issue.id}")%>
    </li>
  </ol>
</nav>
