.badge.sandbox-timer {
  padding: 0.5rem;
  display: flex;
  align-items: center;
  gap: 0.25rem;
  position: fixed;
  right: 12rem;
  top: 0.6rem;
  z-index: 1050;

  @media (max-width: 1024px) {
    right: 10.75rem;
  }

  @media (max-width: 991px) {
    right: 50%;
    transform: translateX(50%);
  }
}
