<div class="tab-pane active" id="properties-tab">
  <h4 class="header-underline">Properties
    <span class="actions pt-1">
      <div class="action">
        <%= link_to edit_project_node_path(@node.project, @node) do %>
          <i class="fa-solid fa-pencil me-1"></i>Edit
        <% end %>
      </div>
    </span>
  </h4>
  <div class="node-content" id="<%= dom_id(@node) %>_content">
    <% if @node.has_any_property? %>
      <% @node.properties.sort.each do |key, value| %>
        <% present [key, value], PropertyPresenter do |property_presenter| %>
          <h4><%= property_presenter.name %></h4>
          <%= property_presenter.value %>
        <% end %>
      <% end %>
    <% else %>
      <%= render 'shared/empty_state',
        docs_link: 'https://dradis.com/support/guides/projects/node_properties.html',
        name: 'node property',
        text: 'Node properties are added after importing information from security scanners. Things like host names, open ports, and running services will all be stored as properties. You can also add your own properties which are stored as structed JSON data.'
      %>
    <% end %>
  </div>
</div>
