<div id="try-pro" class="modal fade" aria-hidden="true">
  <div class="modal-dialog">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" data-behavior="modal-title">Dradis Framework editions</h5>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-hidden="true">
          <span class="visually-hidden">Close modal</span>
        </button>
      </div>
      <div class="modal-body">
        <div class="d-flex h-100 w-100 align-items-center justify-content-center">
          <div class="spinner-border text-primary" role="status"></div>
          <iframe data-url="https://dradis.com/pro/editions.html"></iframe>
        </div>
      </div>
      <div class="modal-footer">
        <a href="javascript:void(0)" data-bs-dismiss="modal" class="btn btn-primary">Close</a>
      </div>
    </div>
  </div>
</div>
