<div class="inner-content">
  <%= render 'layouts/hera/sidebar_collection',
    category_id: nil,
    collection: @sorted_cards,
    name: 'Tasks',
    new_path: new_project_board_list_card_path(current_project, @board, @list, @card)
  %>

  <!-- Attachments -->
  <%= render partial: 'attachments/attachment_box', locals: { attachments_node: current_project.plugin_uploads_node } %>
</div>
