<div id="modal_rename_node" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="modal-title" aria-hidden="true">
  <%= simple_form_for [current_project, @node], html: { class: 'form-horizontal', id: 'modal_rename_node_form' } do |f| %>
    <div class="modal-dialog">
      <div class="modal-content">
        <div class="modal-header">
          <h5 class="modal-title" id="modal-title">Rename <%= @node.label%> node</h5>
          <button type="button" class="btn-close" data-bs-dismiss="modal" aria-hidden="true">
            <span class="visually-hidden">Close modal</span>
          </button>
        </div>
        <div class="modal-body">
          <%= f.input :label, label: "New name", input_html: { id: 'node_new_label' } %>
        </div>
        <div class="modal-footer">
          <button class="btn btn-primary">Rename</button>
          <button class="btn" type="button" data-bs-dismiss="modal" aria-hidden="true">Close</button>
        </div>
      </div>
    </div>
  <% end %>
</div>
