<% if tag %>
  <%= presenter.verb %> the
  <%= link_to tag.display_name, project_tags_path(current_project) %> tag.
<% else %>
  <% if activity.action == 'destroy' %>
    deleted a tag.
  <% else %>
    <%= presenter.verb %> a tag which has since been deleted.
  <% end %>
<% end %>
