<%= flash_messages %>

<%= render partial: 'setup/progress' %>

<%= form_tag(setup_analytics_path) do -%>
  <h1>Making Dradis better, together!</h1>
  <p>We need your help to make Dradis better.</p>
  <p>
    <a
      href="https://dradis.com/why-dradis.html?utm_source=ce&utm_medium=app&utm_campaign=analytics#privacy"
      target="_blank">Privacy and data sovereignty</a>
    are two of the top reasons why teams choose Dradis, that's why we don't
    track individual users, or project data, only aggregated anonymous
    feature usage. We use an open-source and privacy-friendly solution.
  </p>
  <p class="mb-0">Would you help us improve?</p>

  <div class="d-flex justify-content-center gap-4 my-5">
    <%= button_tag name: 'analytics', value: '0', class: 'btn btn-outline-primary m-0' do %>
      No thanks. <i class="fa-solid fa-long-arrow-right"></i>
    <% end %>
    <%= button_tag name: 'analytics', value: '1', class: 'btn btn-primary m-0' do %>
      Yes, I'd like to help! <i class="fa-solid fa-long-arrow-right"></i>
    <% end %>
  </div>

  <p class="small text-center">
    Read the <a
      href="https://dradis.com/ce/privacy.html?utm_source=ce&utm_medium=app&utm_campaign=analytics"
      target="_blank">Privacy FAQ</a> or <a
      href="https://github.com/search?q=repo%3Adradis%2Fdradis-ce%20plausible&type=code"
      target="_blank"><i class="fab fa-github"></i> follow the code</a>.
  </p>
<% end %>
