  <td>
    <%= presenter.avatar_with_link(size: 50, style: 'border-radius: 50%;') %>
  </td>

  <td colspan="5" style="padding-left: 0; font-weight: 400;">
    <%= presenter.render_title %>
    <span style="font-size: 80%; color: #777; white-space: nowrap;">
      <%= presenter.created_at %>
    </span>
  </td>
