<% field_row = render partial: 'field', locals: { index: @index } %>
var fieldGroup = $('<%= escape_javascript(field_row) %>');
$('[data-behavior~=textile-form-body]').append(fieldGroup);

$('.textile').data('plugin_textile').bindFieldGroup(fieldGroup);

$('[data-behavior~=rich-toolbar]', fieldGroup).each(function() {
  new EditorToolbar($(this));
});
