<%= turbo_stream.append "thread_#{@inline_thread.id}_comments" do %>
  <%= render 'inline_threads/inline_comment', comment: @comment %>
<% end %>

<%= turbo_stream.replace "thread_#{@inline_thread.id}_reply_form" do %>
  <%= render 'inline_threads/reply_form', inline_thread: @inline_thread %>
<% end %>
