<% if row.type_id == Node::Types::HOST %>
  <span class="fa-solid fa-laptop"></span>
<% else %>
  <span class="fa-regular fa-folder"></span>
<% end %>

<%= link_to row.label, project_node_path(row.project, row), class: "search-match-title" %>
<p class="result-details">Last updated: <%= local_time_ago(row.updated_at) %></p>
