<li class="nav-item">
  <a href="#plugin-word" class="nav-link" data-bs-toggle="tab">
    <i class="fa-solid fa-file-word fa-fw"></i>Word
  </a>
</li>
<li class="nav-item">
  <a href="#plugin-excel" class="nav-link" data-bs-toggle="tab">
    <i class="fa-solid fa-file-excel fa-fw"></i>Excel
  </a>
</li>
