.dropdown {
  position: relative;
}

.dropdown-menu {
  background-color: var(--primary-bg);
  border: 1px solid var(--border-color);
  box-shadow: 0 2px 3px 0 rgba(33, 55, 74, 0.2);
  font-size: 0.9rem;
  margin: 0;
  max-height: calc(100vh - 10rem);
  overflow-y: auto;
  padding: 0.25rem 0;
  z-index: 4;

  .dropdown-divider {
    border-top: 1px solid var(--border-color);
  }

  .dropdown-item {
    align-items: center;
    color: var(--text-link);
    display: flex;
    transition: color 0s;
    font-weight: inherit;

    &:active,
    &:hover {
      color: var(--text-link-hover);
      background-color: var(--secondary-bg);
    }

    &.active {
      background-color: var(--secondary-bg);
      color: var(--text-default);
      font-weight: 600;
    }

    i {
      margin-right: 0.25rem;
    }

    input[type='checkbox'] {
      margin-right: 0.5rem;
    }

    label {
      margin-bottom: 0;
    }
  }

  .dropdown-item-text {
    color: var(--text-default);
  }
}
