<% commentable = comment.commentable %>
<% if commentable.title? %>
commented on the <%= "#{commentable.title} #{comment.commentable_type.demodulize}" %>.
<% else %>
commented on <%= "#{comment.commentable_type.demodulize} ##{commentable.id}" %>.
<% end %>
