<p class="me-auto mt-3">Add issues using one of these methods:</p>
<div class="d-flex justify-content-between">
  <div class="row mb-4">
    <div class="col-xl-4 mt-3">
      <div class="card add-issues">
        <div class="card-header">
          <p class="card-title">Manually</p>
        </div>
        <div class="card-body">
          <p>
            Use  
            <%= link_to 'javascript:void(0)', data: { behavior: 'issues-dropdown-toggle' } do -%>
              <i class="fa-solid fa-plus me-1"></i>New Issue 
            <% end %>
            and type your <em>Description</em> and
            <em>Recommendation</em>.
          </p>
        </div>
      </div>
    </div>
    <div class="col-xl-4 mt-3">
      <div class="card add-issues">
        <div class="card-header">
          <p class="card-title">From a scanning tool</p>
        </div>
        <div class="card-body">
          <p>Click 
            <%= link_to main_app.project_upload_manager_path(current_project) do-%>
              <i class="fa-solid fa-cloud-upload fa-lg"></i> Upload
            <% end %>
            in the top navigation bar.
          </p>
          <p>
            All the usual suspects are supported:
            <a href="https://dradis.com/integrations/" target="_blank">Nessus, Nmap, Burp...</a>
          </p>
        </div>
      </div>
    </div>
    <div class="col-xl-4 mt-3">
      <div class="card add-issues">
        <div class="card-header">
          <div class="card-title">From a library</div>
        </div>
        <div class="card-body">
          <%= render 'issues/empty_import_ce' %>
        </div>
      </div>
    </div>
  </div>
</div>
