<%# This alert is shown by activities/poller.js if another user deletes the
  current board / a board in boards#index %>
<div id="board-deleted-alert" class="alert alert-danger d-none">
  <p class="mb-0">
    <strong>Warning</strong>.
    This methodology has been deleted by another user since you started
    viewing it.
  </p>
</div>
