<div class="content-textile" data-behavior="content-textile">
  <div class="table-wrapper">
    <table>
      <thead>
        <tr>
          <% Node::Properties::SERVICE_KEYS.each do |key| %>
            <th><%= key.to_s.titleize %></th>
          <% end %>
        </tr>
      </thead>
      <tbody>
        <% services.each do |service| %>
          <tr>
            <% Node::Properties::SERVICE_KEYS.each do |key| %>
              <td><%= service[key] %></td>
            <% end %>
          </tr>
        <% end %>
      </tbody>
    </table>
  </div>
</div>
