<div
  id="modal-list-new"
  class="modal fade boards-modal"
  tabindex="-1"
  role="dialog"
  aria-labelledby="modal-list-header"
  aria-hidden="true"
>
  <div class="modal-dialog">
    <div class="modal-content">
      <%= simple_form_for [current_project, @board, List.new], html: { novalidate: false } do |f| %>
        <div class="modal-header">
          <h5 class="modal-title" id="modal-list-header">Add new list</h5>
          <button type="button" class="btn-close" data-bs-dismiss="modal" aria-hidden="true">
            <span class="visually-hidden">Close modal</span>
          </button>
        </div>

        <div class="modal-body">
          <%= f.input :name, required: true, input_html: { id: 'new_list_name' } %>
        </div>

        <div class="modal-footer">
          <input type="submit" value="Add list" class="btn btn-primary" />
          <button class="btn" type="button" data-bs-dismiss="modal" aria-hidden="true">Close</button>
        </div>
      <% end %>
    </div>
  </div>
</div>
