<div class="header">
  <div class="header-inner">
    <h5 class="header-name font-light">Update State</h5>
    <div class="options">
      <%= link_to "#update-state", data: { bs_toggle: 'collapse', behavior: 'collapse-collection' }, class: local_assigns.fetch(:collapse_class, '') do %>
        <i class="fa-solid fa-chevron-up" data-behavior="toggle-chevron"></i><span class="visually-hidden">Toggle update state</span>
      <% end %>
    </div>
  </div>
</div>

<div id="update-state" class="note-list qa-list collapse show">
  <div class="btn-group mb-4">
    <%= button_to 'Draft', project_qa_issue_path(current_project, id: @issue, state: 'draft'), method: :put, class: 'btn btn-outline-primary rounded-start' %>
    <div class="btn-placeholder rounded-0">Review</div>
    <% if can?(:publish, current_project) %>
      <%= button_to 'Published', project_qa_issue_path(current_project, id: @issue, state: 'published'), method: :put, class: 'btn btn-outline-primary rounded-end' %>
    <% else %>
      <div class="btn-placeholder disabled rounded-end" data-bs-toggle="tooltip" data-bs-title="You are not a Reviewer for this project.">Published</div>
    <% end %>
  </div>
</div>
