// Inline thread highlights on issue body text
.inline-thread-highlight {
  background-color: rgba($yellow-300, 0.3);
  border-bottom: 2px solid rgba($yellow-500, 0.6);
  cursor: pointer;
  transition: background-color 0.2s;

  &:hover {
    background-color: rgba($yellow-300, 0.5);
  }

  &.resolved {
    background-color: rgba($green-500, 0.15);
    border-bottom: 2px dashed rgba($green-500, 0.4);
  }

  &.outdated {
    background-color: rgba($orange, 0.15);
    border-bottom: 2px dotted rgba($orange, 0.4);
  }
}

// Inline comment selection button (follows .selection-quote-button pattern)
.inline-comment-button {
  align-items: center;
  background-color: var(--secondary-bg);
  border: 1px solid var(--border-color);
  border-radius: 25px;
  box-shadow: 0 20px 30px 0 rgba($shadow-color-dark, 0.1);
  cursor: pointer;
  display: flex;
  justify-content: center;
  padding: 0.5rem;
  position: absolute;
  user-select: none;
  width: auto;
  z-index: 3;

  &:after {
    border: 0.5rem solid;
    border-color: var(--secondary-bg) transparent transparent;
    content: '';
    height: 0;
    left: 1rem;
    position: absolute;
    top: 98%;
    width: 0;
  }

  &:before {
    border: 0.5rem solid;
    border-color: var(--border-color) transparent transparent;
    content: '';
    height: 0;
    left: 1rem;
    position: absolute;
    top: 102%;
    width: 0;
  }

  &:hover {
    background-color: var(--secondary-bg-subtle);

    &::after {
      border-color: var(--secondary-bg-subtle) transparent transparent;
    }
  }
}

.inline-thread-comment {
  @include comment-item;

  &:last-child {
    border-bottom: none !important;
  }

  .content {
    p:last-child {
      margin-bottom: 0;
    }
  }
}
