<div class="col-lg-10">
  <p>You can create a methodology template for a specific engagement type like infrastructure, web application, or code reviews based off of your existing workflow. Once the template is created you can quickly apply it to future projects so you don't miss any steps.</p>
</div>

<div class="col-lg-10 col-xl-6 my-4">
  <p>Get started quickly by using templates that have been created by us or the <strong>Dradis Community</strong>:</p>
  <ul class="fa-ul">
    <li><i class="fa-solid fa-li fa-chevron-right"></i><a href="https://dradis.com/academy/industry/compliance/hipaa/" target="_blank">HIPAA Compliance Audit Protocol</a></li>
    <li><i class="fa-solid fa-li fa-chevron-right"></i><a href="https://dradis.com/academy/industry/compliance/ptes/" target="_blank">Penetration Testing Execution Standard (PTES)</a></li>
    <li><i class="fa-solid fa-li fa-chevron-right"></i><a href="https://dradis.com/academy/industry/compliance/oscp/" target="_blank">Offensive Security Certified Professional (OSCP)</a></li>
    <li><i class="fa-solid fa-li fa-chevron-right"></i><a href="https://dradis.com/academy/industry/compliance/owasp/" target="_blank">OWASP Testing Guide</a></li>
  </ul>
  <p>
    You can also find more tamplates in our portal:
    <a href='https://portal.securityroots.com/extras/resources#testing_methodologies' target='_blank'>OSSTMM, SANS SWAT, Web Application Hacker's Handbook...</a>
  </p>
</div>
