<li>
  <a href="javascript:void(0)" class="js-try-pro dropdown-item" data-term="contact-support" data-url="https://dradis.com/pro/pages/support.html">Contact support</a>
</li>
<li>
  <a href="https://dradis.slack.com/" target="_blank" class="dropdown-item">Chat on Slack</a>
</li>
