<div class="inline-thread-comment py-2 border-bottom" id="inline_comment_<%= comment.id %>">
  <div class="d-flex">
    <%= avatar_image(comment.user, size: 30) %>
    <div class="w-100">
      <div class="d-flex flex-column">
        <span class="user"><%= comment.user&.name || 'Unknown' %></span>
        <span class="time"><%= local_time_ago(comment.created_at) %></span>
      </div>
      <div class="content mt-1"><%= comment_formatter(comment.content) %></div>
    </div>
  </div>
</div>
