<%# This alert is shown by activities/poller.js if another user deletes the
  current card %>
<div id="card-deleted-alert" class="alert alert-danger d-none">
  <p class="mb-0">
    <strong>Warning</strong>. This task has been deleted by another user since
    you started viewing it.
  </p>
</div>

<%# This alert is shown by activities/poller.js if another user updates the
  current card %>
<div id="card-updated-alert" class="alert alert-info d-none">
  <%# content is set dynamically with js at show time %>
</div>

<%# This alert is shown by activities/poller.js if another user deletes the
  current board %>
<div id="board-deleted-alert" class="alert alert-danger d-none">
  <p class="mb-0">
    <strong>Warning</strong>. This methodology has been deleted by another user since
    you started viewing it.
  </p>
</div>

<%# This alert is shown by activities/poller.js if another user deletes the
  current list %>
<div id="list-deleted-alert" class="alert alert-danger d-none">
  <p class="mb-0">
    <strong>Warning</strong>. This list has been deleted by another user since
    you started viewing it.
  </p>
</div>
