<span class="dropdown-item dots-dropdown-header" tabindex="-1">Send to...</span>
<% sync_plugins = Dradis::Plugins::with_feature(:issue_sync) %>

<% if sync_plugins.any? %>
  <% sync_plugins.each do |plugin| %>
    <%=
      plugin_path = ActiveSupport::Inflector.underscore(ActiveSupport::Inflector.deconstantize(plugin.name))
      render partial: "#{plugin_path}/issues/send_to_menu"
    %>
  <% end %>
<% end %>

<% unless defined?(Dradis::Pro) %>
  <% if sync_plugins.any? %>
    <div class="divider"></div>
  <% end %>

  <%= render 'static_pages/send_to_menu'%>
<% end %>
