<div 
  class="d-inline-flex align-items-center fs-6 fw-light" 
  data-behavior="liquid-spinner"
>
  <span class="mx-2">-</span>
  <%= spinner_tag spinner_class: 'spinner-border-sm text-primary', align: 'start', inline: true %>
  <span class="ms-2 text-nowrap">Loading liquid dynamic content</span>
</div>
