<div id="modal-console" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="modal-title" aria-hidden="true">
  <div class="modal-dialog">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="modal-title">Output console</h5>
      </div>
      <div class="modal-body">
        <%= content_tag :div,
                        id: 'result',
                        style: 'display:none',
                        data: {
                          url: main_app.status_console_index_path
                        }  do %>
          <div>
            This task can take some time and will be executed in the background.<br>
            Progress can be tracked here:
          </div>
          <div id="console"></div>
        <% end %>
      </div>
      <div class="modal-footer d-none">
        <button class="btn btn-primary" type="button" data-bs-dismiss="modal" aria-hidden="true">Done!</button>
      </div>
    </div>
  </div>
</div>
