<%= render 'error', 
  error_title: 'Bad request',
  status_code: 400,
  quote: "I don't think I want to ask you how you got it, because I need you on this mission.",
  author: 'Captain Apollo',
  icon: [5, 'Satellite']
%>
