<p>You'll need an import plugin like:</p>
<ul class="fa-ul">
  <li><i class="fa-solid fa-li fa-chevron-right"></i><a href="https://dradis.com/integrations/mediawiki.html?utm_source=ce&utm_medium=app" target="_blank">MediaWiki</a></li>
  <li><i class="fa-solid fa-li fa-chevron-right"></i>
    <%= link_to static_issuelib_path do %>
      <i class="fa-solid fa-book"></i> Built-in IssueLibrary
    <% end %>
  </li>
</ul>
