<%= render 'error', 
  error_title: 'Lost in space?',
  status_code: 404,
  quote: "Just because you don't know your direction doesn't mean you don't have one.",
  author: 'Dreilide "Slick" Thrace',
  icon: [1, 'Astronaut']
%>
