<nav class="navbar navbar-expand-lg sub-nav">
  <div class="container-fluid">
    <div class="collapse navbar-collapse dual-nav" data-behavior="navbar-collapse">
      <%= render partial: locals[:sub_nav_content] %>
    </div>
  </div>
</nav>
