<div class="main-sidebar sidebar resizable" data-behavior="sidebar resizable" data-storage-key="sidebar-expanded">
  <div class="resize-handle" data-behavior="resize-handle"></div>
  <div class="sidebar-toggle">
    <a href="javascript:void(0)" class="sidebar-toggle-link" data-behavior="sidebar-toggle">
      <i class="fa-solid fa-chevron-left sidebar-toggle-icon"></i>
      <span class="visually-hidden">Toggle sidebar</span>
    </a>
  </div>
  <div class="sidebar-content" data-behavior="sidebar-content">
    <%= render 'layouts/hera/nodes' %>
  </div>
</div>
