// Grammar/style suggestion highlights
.grammar-suggestion-highlight {
  background-color: transparent;
  color: inherit;
  cursor: pointer;
  text-decoration: underline wavy var(--badge-lavender-color);
  text-underline-offset: 3px;
}
