<div id="thread_<%= inline_thread.id %>_reply_form">
  <%= form_with url: inline_thread_comments_path(inline_thread) do |f| %>
    <%= f.text_area :content,
          name: 'comment[content]',
          class: 'form-control form-control-sm mb-2',
          placeholder: 'Reply...',
          rows: 2 %>
    <%= f.submit 'Reply', class: 'btn btn-sm btn-primary' %>
  <% end %>
</div>
