<% content_for :title, 'Edit issue' %>

<% content_for :sidebar do %>
  <%= render 'sidebar' %>
<% end %>

<% content_for :breadcrumbs do %>
  <nav>
    <%= render partial: 'breadcrumbs' %>
  </nav>
<% end %>

<%= render_view_hooks 'issues/edit-content' %>

<div class="content-container" id="issues_editor">
  <div class="note-text-inner">
    <h4 class="header-underline">Edit issue (<%= @issue.state.humanize %>)</h4>
    <!-- This div is needed to allow correct tabbing order in Chrome with page is loaded with turbolinks -->
    <div class="autofocus" autofocus="true" tabindex="1"></div>
    <%= render 'form' %>
  </div>
</div>
