body.issues.edit,
body.issues.new,
body.qa-issues.edit {
  .tag-input {
    display: flex;
    align-items: center;
    position: absolute;
    right: 0;
    top: 0;
    padding: 0.6rem;

    .btn {
      background: var(--primary-bg);
      color: var(--text-default);
    }
  }
}

body.issues.edit {
  #cvss-tabs.nav-pills {
    .nav-link.active {
      background-color: var(--brand-bg);
      color: $white;
    }
  }
}

body.issues.index {
  .add-issues {
    border: 1px solid var(--brand-bg);
    height: 100%;

    .card-body {
      display: flex;
      flex-direction: column;
      justify-content: center;
    }

    .card-header {
      background: var(--brand-bg);
      color: $white;

      .card-title {
        margin-bottom: 0;
        text-transform: capitalize;
      }
    }
  }

  .empty-state {
    &-actions {
      margin-top: 0;
    }

    &-body-text {
      text-align: left;
    }
  }

  .tab-content.outer-tab {
    border-right: 1px solid var(--border-color);
    border-bottom: 1px solid var(--border-color);
    border-left: 1px solid var(--border-color);
  }

  .tab-pane {
    padding: 1.5rem;
  }
}

body.issues.show {
  .evidence-content {
    padding-left: 2rem;

    .content-textile {
      border-left: 6px solid var(--border-color);
      margin-left: 1rem;
      padding-left: 1rem;
    }

    .tab-content {
      padding: 1rem 0 0 1rem;
    }
  }
}
