$('[data-behavior~=comment-list]').append("<%= j render 'comments/comment', comment: @comment %>")

$('[data-behavior~=add-comment] textarea').val('')

var submit = $('[data-behavior~=add-comment] input[type=submit]')
submit.attr('disabled', false).val(submit.data('disable-with'))

$('#<%= dom_id(@comment) %>').find('.actions').addClass('current_user')

$('[data-notice~=no-comments]').hide()

$('[data-behavior~=content-textile]').each(function() {
  new QuoteSelector(this);
});

$('[data-behavior~=subscribe]').addClass('d-none');
$('[data-behavior~=unsubscribe]').removeClass('d-none');
