<% content_for :title, 'Notifications' %>

<% content_for :breadcrumbs do %>
  <% if @current_project %>
    <ol class="breadcrumb">
      <li class="breadcrumb-item"><%= link_to current_project.name, project_path(current_project) %></li>
      <li class="breadcrumb-item active">Notifications</li>
    </ol>
  <% end %>
<% end %>

<div class="content-container">
  <h4 class="header-underline w-100">
    <%= render partial: 'notifications/header' %>
  </h4>
  <%= render partial: 'notifications/notifications' %>
</div>
