<div id="import_results_content" class="results collapse">
  <div class="page page-none">
    <div class="header">
      <div class="header-inner">
        <h2>Results</h2>
      </div>
    </div>
    <div class="note-list issue-list">
      <div class="list-item">
        <div class="note loading"><%= image_tag 'jquery.textile.loading.gif' %></div>
      </div>
      <div class="list-item">
        <div class="note dradis-placeholder">(no results)</div>
      </div>
    </div>
  </div>
</div>
