.card.tool-disabled {
  background-color: var(--secondary-bg);
}

.provider-detail-label {
  color: var(--text-muted);
  font-size: 0.75rem;
  margin-right: 0.2rem;
}

.provider-detail-value {
  background: none;
  color: var(--bs-body-color);
  font-size: 0.75rem;
  padding: 0;
}

.provider-details {
  display: flex;
  flex-wrap: wrap;
  gap: 1rem;
}

.provider-icon {
  height: 1.5rem;
  object-fit: contain;
  width: 1.5rem;
}

.provider-icon-wrap {
  align-items: center;
  background: var(--secondary-bg);
  border: 1px solid var(--border-color);
  border-radius: 0.5rem;
  display: flex;
  height: 2.5rem;
  justify-content: center;
  padding: 0.375rem;
  width: 2.5rem;
}

.provider-list .provider-row:last-child {
  border-bottom: none;
  margin-bottom: 0;
  padding-bottom: 0;
}

.provider-row {
  align-items: center;
  border-bottom: 1px solid var(--bs-border-color);
  display: flex;
  justify-content: space-between;
  margin-bottom: 1rem;
  padding-bottom: 0.5rem;
  padding-top: 0.5rem;
}
