body.projects {
  .summary-panel {
    #boards-summary {
      display: flex;
      flex-wrap: wrap;

      &.loading {
        background: image_url('loading.gif') no-repeat center;
      }

      .pie-chart {
        width: 50%;
      }

      svg.legend text {
        fill: var(--text-default);
      }
    }

    .empty-state {
      &-actions {
        margin-top: 1.5rem;
      }

      &-icon {
        padding: 0.75rem;

        img {
          width: 7rem;
        }
      }

      &-title {
        margin: 2rem 0 1rem;
      }
    }

    #issue-chart {
      display: flex;
      justify-content: center;
      align-items: center;

      .bar.untagged,
      .counter.untagged,
      .tick.untagged {
        fill: var(--untagged-color);
      }

      svg text {
        font-size: 14px;
      }
    }

    #issues-accordion {
      margin-top: 1rem;

      .card {
        margin-bottom: 1rem;

        .card-body {
          .list-group-item {
            background-color: var(--primary-bg);
            border: none;
            border-color: var(--border-color);
            color: var(--text-default);
            transition: background-color 0.2s ease-in-out;

            &.active {
              color: $white;

              &:hover {
                border-color: var(--border-color);
                color: var(--text-link);
              }
            }

            &:hover {
              background-color: var(--primary-bg-subtle);
            }

            li {
              transition: color 0.2s ease-in-out;
            }
          }
        }

        .card-header {
          color: $white;

          h5 {
            margin-bottom: 0;
          }
        }

        &:last-of-type {
          margin-bottom: 0;
        }

        &.untagged {
          border-color: var(--untagged-color);

          .card-header {
            background-color: var(--untagged-color);
            color: var(--untagged-text);
          }

          .fa-bug {
            color: var(--untagged-color);
          }
        }
      }
    }
  }
}
