<ul class="tabs-container search-nav nav nav-tabs">
  <li class="nav-item">
    <%= link_to search_filter_path(scope: :all), id: 'all', :class => @scope == :all ? 'nav-link active' : 'nav-link' do %>
      All (<%= search.total_count %>)
    <% end %>
  </li>
  <li class="nav-item">
    <%= link_to search_filter_path(scope: :nodes), id: 'nodes', :class => @scope == :nodes ? 'nav-link active' : 'nav-link' do %>
      <i class="fa-solid fa-sitemap"></i> Nodes (<%= search.nodes_count %>)
    <% end %>
  </li>
  <li class="nav-item">
    <%= link_to search_filter_path(scope: :notes), id: 'notes', :class => @scope == :notes ? 'nav-link active' : 'nav-link' do %>
      <i class="fa-regular fa-file-text"></i> Notes (<%= search.notes_count %>)
    <% end %>
  </li>
  <li class="nav-item">
    <%= link_to search_filter_path(scope: :evidence), id: 'evidences', :class => @scope == :evidence ? 'nav-link active' : 'nav-link' do %>
      <i class="fa-regular fa-flag"></i> Evidence (<%= search.evidence_count %>)
    <% end %>
  </li>
  <li class="nav-item">
    <%= link_to search_filter_path(scope: :issues), id: 'issues', :class => @scope == :issues ? 'nav-link active' : 'nav-link' do %>
      <i class="fa-solid fa-bug"></i> Issues (<%= search.issues_count %>)
    <% end %>
  </li>
</ul>
