<%# self.formats += ['html'] %>
<% if @issue.destroyed? %>
{
  "success": true,
       "id": <%= @issue.id %>,
      "msg": "Issue deleted"
}
<% else %>
{
  "success": false,
      "msg": "<%= j "Error while deleting issue: #{@issue.errors}" %>",
   "errors": <%= j @issue.errors.to_json %>"
  }
<% end %>
