.dots-dropdown {
  align-items: center;
  cursor: pointer;
  display: inline-flex;
  height: 1.75rem;
  justify-content: center;
  margin-left: auto;
  transition: all 0.2s ease-in-out;
  width: 1.75rem;

  .dots-dropdown-header {
    font-weight: 400 !important;

    &:hover {
      color: var(--text-link) !important;
      background-color: initial !important;
    }

    &:not(:first-child) {
      border-top: 1px solid var(--border-color);
      margin-top: 0.3rem;
      padding-top: 0.3rem;
    }

    &:not(:has(+ .dropdown-item)) {
      display: none;
    }
  }

  .dropdown-menu {
    cursor: default;
  }

  .dropdown-toggle {
    padding: 0.6rem 0.7rem;

    &::after {
      display: none;
    }

    .fa-lg {
      font-size: 1.15rem;
    }
  }

  &:hover,
  &.show {
    .dropdown-toggle {
      color: var(--text-link-hover);
    }
  }
}
