<div class="actions">
  <span class="action">
    <%= link_to edit_project_node_evidence_path(@node.project, @node, @evidence) do %>
      <i class="fa-solid fa-pencil fa-fw"></i> Edit
    <% end %>
  </span>
  <li class="dropdown dots-dropdown">
    <a href="#" class="dropdown-toggle" data-bs-toggle="dropdown"><i class="fa-solid fa-ellipsis-h fa-lg"></i><span class="visually-hidden">Toggle menu</span></a>
    <div class="dropdown-menu">
      <%= link_to [current_project, @node, @evidence],
        class: 'dropdown-item text-error-hover',
        data: { confirm: "Are you sure?\n\nProceeding will delete this evidence from the associated node." },
        method: :delete do %>
        <i class="fa-solid fa-trash fa-fw"></i> Delete
      <% end %>
      <a href="#modal_move_evidence" class="dropdown-item" tabindex="-1" data-bs-toggle="modal"><i class="fa-solid fa-mail-forward fa-fw"></i> Move</a>
      <%= render partial: 'subscriptions/actions', locals: { subscribable: @evidence, dots_menu: true } %>
      <%= link_to(project_node_evidence_revisions_path(@node.project, @node, @evidence), class: 'dropdown-item') do %>
        <i class="fa-solid fa-history fa-fw"></i> View History
      <% end %>
    </div>
  </li>
</div>
