<% if issue %>
  <% if issue.title? %>
    <%= presenter.verb %> the <%= link_to issue.title, project_issue_path(current_project, issue) %> <%= activity.action == 'state_change' ? "issue's state" : 'issue' %>.
  <% else %>
    <%= presenter.verb %> <%= link_to "Issue ##{issue.id}", project_issue_path(current_project, issue) %>.
  <% end %>
<% else %>
  <% if activity.action == 'destroy' %>
    deleted an issue.
  <% else %>
    <%= presenter.verb %> an issue which has since been deleted.
  <% end %>
<% end %>
