body.unauthenticated:not(.contributors).december {
  @include easter-egg-theme(#ec2029);

  &::after,
  &::before {
    content: '';
    inset: 0;
    position: fixed;
    z-index: -1;
  }

  &::after {
    background-image: image-url('december/lights.png');
    background-position: top;
    background-size: 30rem;
    height: 5.25rem;
  }

  &::before {
    background-image: image-url('december/snow.svg');
    background-position: bottom;
    background-repeat: no-repeat;
    background-size: 100% 16rem;
  }
}
