<% if evidence %>
  <% issue = evidence.issue %>
  <% node  = evidence.node %>
  <%= presenter.verb %> <%= link_to 'a piece of evidence', [current_project, node, evidence] %>
  for
  <%= link_to issue.title || "Issue #{issue.id}", [current_project, evidence.issue] %> at <%= link_to node.label, [current_project, node] %>.
<% else %>
  <% if activity.action == 'destroy' %>
    deleted a piece of evidence.
  <% else %>
    <%= presenter.verb %> a piece of evidence which has since been deleted.
  <% end %>
<% end %>
