<li><%= link_to 'Configure Integrations', main_app.project_configurations_path(current_project), class: 'dropdown-item' %></li>
<li><%= link_to 'Manage Tags', main_app.project_tags_path(current_project), class: 'dropdown-item' %></li>
