<%= render 'error', 
  error_title: 'Unprocessable Entity',
  status_code: 422,
  quote: 'The Cylons never asked us what we wanted. Welcome to the big leagues.',
  author: 'Commander Adama',
  icon: [2, 'Meteor']
%>
