<nav>
  <ol class="breadcrumb">
    <li class="breadcrumb-item">
        <%= link_to current_project.name, project_path(current_project) %>
      </li>
    <li class="breadcrumb-item">
      <a href="javascript:void(0)" data-behavior="sidebar-toggle">Nodes</a>
    </li>
    <li class="breadcrumb-item" data-node-id="<%= @node.id %>">
      <%= link_to @node.label, main_app.project_node_path(@node.project, @node, tab: 'evidence-tab') %>
    </li>
    <%= content_tag :li, class: 'breadcrumb-item active' do %><%= @evidence.persisted? ? @evidence.title : 'New Evidence' %><% end -%>
  </ol>
</nav>
