@import '_bootstrap';
@import '../hera/variables';
@import '../hera/themes';
@import '../hera/modules/divider';
@import 'font-awesome';

html {
  font-size: 16px;
}

body {
  height: 100vh;
  margin: 0;
  position: relative;
}

a {
  color: var(--text-link);
  text-decoration: none;
  transition: color 0.2s ease-in-out;

  &:hover {
    color: var(--text-link-hover);
  }
}

.btn {
  &:hover {
    i {
      transform: translateX(5px);
    }
  }

  i {
    margin-left: 0.5rem;
    transition: transform 0.2s ease-in-out;
  }
}

.btn-experience {
  border: 1.5px solid var(--text-link);
  border-radius: 5px;
  box-shadow: 0px 0px 0px 0px rgba(62, 66, 66, 0.1);
  color: var(--text-link);
  height: 100%;
  padding: 1.375rem 1.85rem;
  text-align: left;
  transition: background-color 0.2s ease-in-out, border-color 0.2s ease-in-out,
    box-shadow 0.2s ease-in-out, color 0.2s ease-in-out;
  width: 100%;

  &:focus,
  &:hover,
  &:active,
  &:not(:disabled):not(.disabled):active {
    background: var(--text-link);
    border-color: var(--text-link);
    box-shadow: 0px 0px 50px 0px rgba(62, 66, 66, 0.1);
    color: var(--text-inverted);
  }

  p {
    color: inherit;
    font-weight: bold;
  }

  span {
    color: inherit;
    display: block;
    font-size: 0.8rem;
    position: relative;
    text-align: left;

    i {
      bottom: 0;
      color: inherit;
      font-size: 1rem;
      position: absolute;
      right: 0;
    }
  }
}

.btn:not(.btn-experience) {
  padding: 0.375rem 1.25rem;

  &[type='submit'] {
    display: block;
    margin: 2rem auto;
  }
}

.btn-primary {
  background-color: var(--brand-bg);
  border-color: var(--brand-bg);
  color: $white;

  &:hover,
  &:focus,
  &:focus-visible,
  &:active,
  &:not(:disabled):not(.disabled):active {
    background-color: darken($primary, 10);
    border-color: darken($primary, 10);
    color: $white;
  }
}

.btn-outline-primary {
  border-color: var(--text-link);
  color: var(--text-link);

  &:hover,
  &:focus,
  &:focus-visible,
  &:active,
  &:not(:disabled):not(.disabled):active {
    background: var(--text-link);
    border-color: var(--text-link);
    color: var(--text-inverted);
  }
}

.copyright {
  font-size: 80%;
  text-align: center;
  width: 100%;
}

.form-control,
.form-select {
  background-color: transparent;
  border-color: var(--border-color);
  color: var(--text-default);

  &:focus {
    background: transparent;
    border-color: var(--brand-bg);
    box-shadow: 0 0 0 0.2rem
      color-mix(in srgb, var(--brand-bg) 50%, transparent);
    color: var(--text-default);
    outline: 0;
  }
}

.h-100vh {
  min-height: 100vh;
}

h1 {
  text-align: center;
  font-size: 1.3rem;
  margin: 3rem 0 2rem;
}

label {
  text-transform: capitalize;
}

.logo {
  margin: 2rem auto -2rem;
  max-width: 150px;
}

.setup-wrapper {
  background: var(--primary-bg-subtle);
  border: 1px solid var(--border-color);
  border-radius: 0.25rem;
  max-width: 600px;
}

.setup-progress {
  margin: 3rem auto 0;
  position: relative;
  width: 66%;

  &:after {
    border-top: 1.5px solid var(--brand-bg);
    content: '';
    display: block;
  }

  &-indicator {
    align-items: center;
    background-color: var(--primary-bg-subtle);
    border: 1.5px solid var(--brand-bg);
    border-radius: 50%;
    display: flex;
    font-size: 0.8rem;
    height: 1.3rem;
    justify-content: center;
    left: calc(50% - 0.65rem);
    position: absolute;
    top: -0.6rem;
    width: 1.3rem;

    &.active {
      background-color: var(--brand-bg);
    }

    &:first-of-type {
      left: 0;
    }

    &:last-of-type {
      left: unset;
      right: 0;
    }
  }
}
