<% if card %>
  <% list    = card.list %>
  <% board   = list.board %>
  <% project = board.project %>
  <%= presenter.verb %> the <%= link_to card.name, [project, board, list, card] %> card
  in the <%= link_to board.name, [project, board] %> methodology.
<% else %>
  <% if activity.action == 'destroy' %>
    deleted a card.
  <% else %>
    <%= presenter.verb %> a card which has since been deleted.
  <% end %>
<% end %>
