<a class="dropdown-item d-flex flex-column align-items-start js-try-pro" data-term="gateway" data-url="https://dradis.com/pro/pages/gateway.html" href="javascript:void(0)">
  <span><i class="fa-solid fa-external-link"></i> Post comment to results portal</span>
</a>
